elephant.test.test_cubic module — Elephant 0.5.0 documentation

# elephant.test.test_cubic module

Unit tests for the CUBIC analysis.

class `elephant.test.test_cubic.` `CubicTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  This test is constructed to check the implementation of the CuBIC method [1]. In the setup function is constructed an neo.AnalogSignal, that represents the Population Histogram of a population of neurons with order of correlation equal to ten. Since the population contu is either equal to 0 or 10 means that the embedded order of correlation is exactly 10. In test_cubic() the format of all the output and the order of correlation of the function jelephant.cubic.cubic() are tested.

  References

  [1]Staude, Rotter, Gruen, (2009) J. Comp. Neurosci

  Methods

  `setUp`()
  `test_cubic`()
  `test_cubic_errors`()
  `test_cubic_ximax`()

`elephant.test.test_cubic.` `suite`()